@@ -3,15 +3,16 @@
 // Use is subject to license terms.
 //
 
-use chrono::{DateTime, Utc};
-use itertools::Itertools;
-use serde::{Deserialize, Serialize};
-use serde_with::{skip_serializing_none, DeserializeFromStr, SerializeDisplay};
 use std::collections::HashMap;
 use std::convert::Infallible;
 use std::fmt;
 use std::ops;
 use std::str;
+
+use chrono::{DateTime, Utc};
+use itertools::Itertools;
+use serde::{Deserialize, Serialize};
+use serde_with::{skip_serializing_none, DeserializeFromStr, SerializeDisplay};
 use uuid::Uuid;
 
 use crate::location::{InvalidRegion, Location};
@@ -23,6 +24,7 @@ pub use cluster::{
     Cluster, ClusterLocationAws, ClusterLocationAzure, ClusterLocations, ClusterName, ClusterToken,
     CreateClusterDto, Provider,
 };
+pub use error::{Error, Permission, StatehubError};
 pub use gcp::GcpRegion;
 pub use helm::Helm;
 pub use state::{
@@ -38,6 +40,7 @@ pub use volume::{
 mod aws;
 mod azure;
 mod cluster;
+mod error;
 mod gcp;
 mod helm;
 mod state;
