@@ -43,9 +43,9 @@ impl str::FromStr for ClusterName {
     }
 }
 
-impl AsRef<Self> for ClusterName {
-    fn as_ref(&self) -> &Self {
-        self
+impl AsRef<str> for ClusterName {
+    fn as_ref(&self) -> &str {
+        self.0.as_ref()
     }
 }
 
@@ -57,6 +57,12 @@ impl ops::Deref for ClusterName {
     }
 }
 
+impl PartialEq<&str> for ClusterName {
+    fn eq(&self, other: &&str) -> bool {
+        self.0.eq(other)
+    }
+}
+
 impl From<AwsRegion> for ClusterLocationAws {
     fn from(region: AwsRegion) -> Self {
         Self {
